@@ -11,7 +11,7 @@ use Exporter::Lite;
 
 our @EXPORT_OK = qw(format_number_mix);
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 our %SPEC;
 
@@ -145,7 +145,7 @@ Lingua::EN::Number::Format::MixWithWords - Format number to a mixture of numbers
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -164,23 +164,31 @@ formatted like a normal number.
 
 None of the functions are exported by default, but they are exportable.
 
-=head2 format_number_mix(%args) -> RESULT
+=head1 SEE ALSO
+
+L<Lingua::EN::Numbers>
+
+L<Number::Format>
+
+=head1 FUNCTIONS
 
 
-Arguments (C<*> denotes required arguments):
+=head2 format_number_mix(%args) -> [status, msg, result, meta]
+
+Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<min_format>* => I<float> (default C<1000000>)
+=item * B<min_format>* => I<float> (default: 1000000)
 
 Number must be larger than this to be formatted as mixture of number and word.
 
-=item * B<min_fraction>* => I<float> (default C<1>)
+=item * B<min_fraction>* => I<float> (default: 1)
 
 Whether smaller number can be formatted with 0,x.
 
-If min_fraction is 1 (the default) or 0.9, 800000 won't be formatted as 0.9
-omillion but will be if min_fraction is 0.8.
+If minB<fraction is 1 (the default) or 0.9, 800000 won't be formatted as 0.9
+omillion but will be if min>fraction is 0.8.
 
 =item * B<num>* => I<float>
 
@@ -194,23 +202,16 @@ Can be negative, e.g. -1 to round to nearest 10, -2 to nearest 100, and so on.
 
 =item * B<scale>* => I<str>
 
-Value must be one of:
-
- ["short", "long"]
-
-
 Pick long or short scale names.
 
-See http://en.wikipedia.org/wiki/Long_scale#Long_scale_countries_and_languages
+See http://en.wikipedia.org/wiki/LongB<scale#Long>scaleB<countries>and_languages
 for details.
 
 =back
 
-=head1 SEE ALSO
+Return value:
 
-L<Lingua::EN::Numbers>
-
-L<Number::Format>
+Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
 
 =head1 AUTHOR
 
@@ -218,7 +219,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Steven Haryanto.
+This software is copyright (c) 2012 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
